Package: tinypkgr
Title: Minimal R Package Development Utilities
Version: 0.2.1
Authors@R: c(
    person("Troy", "Hernandez", email = "troy@cornball.ai", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"))
Description: Lightweight wrappers around 'R CMD INSTALL', 'R CMD check',
    'R CMD build', 'win-builder' uploads, and 'CRAN' submission. Provides
    functions for installing, loading, checking, building, and submitting
    R packages with minimal dependencies (only 'curl' for uploads).
    Background on R package development is in Wickham and Bryan (2023,
    ISBN:9781098134945), "Writing R Extensions"
    <https://cran.r-project.org/doc/manuals/R-exts.html>, and the 'CRAN'
    Repository Policy <https://cran.r-project.org/web/packages/policies.html>.
License: GPL-3
URL: https://github.com/cornball-ai/tinypkgr
BugReports: https://github.com/cornball-ai/tinypkgr/issues
Encoding: UTF-8
Imports: curl
Suggests: tinyrox, tinytest
NeedsCompilation: no
Packaged: 2026-04-22 00:50:16 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph]
Maintainer: Troy Hernandez <troy@cornball.ai>
Repository: CRAN
Date/Publication: 2026-04-22 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 22:51:10 UTC; unix
