# tinyrox says don't edit this manually, but it can't stop you!

export(build)
export(check)
export(check_win_devel)
export(install)
export(load_all)
export(maintainer)
export(reload)
export(submit_cran)
export(use_github_action)
export(use_version)

importFrom(curl,curl_fetch_memory)
importFrom(curl,curl_upload)
importFrom(curl,form_file)
importFrom(curl,handle_setform)
importFrom(curl,new_handle)
