# tinypkgr

Minimal R package development utilities - base R + curl.

## What it does

tinypkgr provides lightweight wrappers around R CMD INSTALL, R CMD check, and CRAN submission utilities.

## Installation

```r
remotes::install_github("cornball-ai/tinypkgr")
```

## Usage

For creating a new package skeleton, use [pkgKitten](https://github.com/eddelbuettel/pkgkitten):

```r
pkgKitten::kitten("mypkg")
```

### Development

```r
library(tinypkgr)

# Source all R files for interactive development
load_all()

# Install package
install()

# Reinstall and reload
reload()

# Run R CMD check
check()
```

### CRAN Release

```r
# Build tarball
build()

# Test on Windows
check_win_devel()

# Submit to CRAN
submit_cran()
```

## Functions

| Function | Purpose |
|----------|---------|
| `use_version()` | Bump DESCRIPTION version + NEWS.md header |
| `use_github_action()` | Write `.github/workflows/ci.yaml` (r-ci) |
| `install()` | R CMD INSTALL wrapper |
| `load_all()` | Source R/ files for dev |
| `reload()` | Reinstall and reload |
| `check()` | R CMD check wrapper |
| `build()` | R CMD build wrapper |
| `maintainer()` | Extract maintainer from DESCRIPTION |
| `check_win_devel()` | Upload to win-builder |
| `submit_cran()` | Submit to CRAN |

## Philosophy

Follows [tinyverse](https://www.tinyverse.org) principles. Only dependency is `curl` (for CRAN/win-builder uploads).

## License

GPL-3
